==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Subscription.pm <==
package WebGUI::i18n::German::Asset_Subscription;
use utf8;
our $I18N = {
  'add subscription' => {
    'lastUpdated' => '1240740261',
    'message' => 'Neues Abonnement hinzufügen'
  },
  'and' => {
    'lastUpdated' => '1226015077',
    'message' => 'und'
  },
  'assetName' => {
    'lastUpdated' => '1240740271',
    'message' => 'Abonnement'
  },
  'association' => {
    'lastUpdated' => '1240779161',
    'message' => 'Mit Abonnement verbinden'
  },
  'association description' => {
    'lastUpdated' => '1240779130',
    'message' => 'Welche/s Abonnement/s wurden mit den generierten Codes abgeschlossen? '
  },
  'batch description' => {
    'lastUpdated' => '1240740441',
    'message' => 'Codeserie Beschreibung'
  },
  'batch description description' => {
    'lastUpdated' => '1241303911',
    'message' => 'Beschreibung der Codeserie'
  },
  'batch id' => {
    'lastUpdated' => '1240740396',
    'message' => 'CodesatzId'
  },
  'batch name' => {
    'lastUpdated' => '1240740426',
    'message' => 'Name der Codeserie'
  },
  'batch name description' => {
    'lastUpdated' => '1240778906',
    'message' => 'Geben Sie eine Bezeichnung für diese Codeserie an'
  },
  'batchDescription' => {
    'lastUpdated' => '1240740538',
    'message' => 'Die Beschreibung der Codeserie, die mit dem Abonnementscode zusammenhängt.'
  },
  'code' => {
    'lastUpdated' => '1240740240',
    'message' => 'Code'
  },
  'code description' => {
    'lastUpdated' => '1240740623',
    'message' => 'Der Abonnementscode, den Sie einlösen möchten'
  },
  'code length' => {
    'lastUpdated' => '1240740682',
    'message' => 'Länge Abonnementscode'
  },
  'code length description' => {
    'lastUpdated' => '1241303410',
    'message' => 'Anzahl der Zeichen in den generierten Codes. Die Länge der Codes soll minimum 10 Zeichen betragen.'
  },
  'code length error' => {
    'lastUpdated' => '1241303975',
    'message' => 'Sie sollten einen Abocode mit einer Länge von 10 bis max. 64 Zeichen eingegeben.'
  },
  'codeControls' => {
    'lastUpdated' => '1241304069',
    'message' => 'Eine Serie von Links für die Erstellung von Codeserien und das Auflisten von Abocodes und Codserien.'
  },
  'codeForm' => {
    'lastUpdated' => '1240779279',
    'message' => 'Das Formular in das der Benutzer seinen Abonnementscode eingeben kann.'
  },
  'codes expire' => {
    'lastUpdated' => '1240740765',
    'message' => 'Codes ungültig ab'
  },
  'codes expire description' => {
    'lastUpdated' => '1240880329',
    'message' => 'Der Abocode muss bis zu diesem Datum eingelöst werden.'
  },
  'continueShoppingUrl' => {
    'lastUpdated' => '1240879864',
    'message' => 'Eine URL zum Reset des Produkts, damit der Benutzer weiter einkaufen kann'
  },
  'create batch error' => {
    'lastUpdated' => '1241304114',
    'message' => 'Es gab einen Fehler bei der Erstellung von der Codeserie.'
  },
  'create batch menu' => {
    'lastUpdated' => '1241304204',
    'message' => 'Codeserie generieren'
  },
  'creation date' => {
    'lastUpdated' => '1240778919',
    'message' => 'Erstellungsdatum'
  },
  'dateUsed' => {
    'lastUpdated' => '1243494558',
    'message' => 'Datum Inanspruchnahme'
  },
  'default thank you message' => {
    'lastUpdated' => '1254902412',
    'message' => 'Das Abonnement wurde in den Warenkorb gelegt.'
  },
  'delete batch confirm' => {
    'lastUpdated' => '1250942315',
    'message' => 'Möchten Sie diese Codeserie wirklich löschen?'
  },
  'delete codes' => {
    'lastUpdated' => '1240779181',
    'message' => 'Alle diese Codes löschen'
  },
  'delete subscription confirm' => {
    'lastUpdated' => '1241304136',
    'message' => 'Möchten Sie dieses Abonnement wirklich löschen?'
  },
  'display all' => {
    'lastUpdated' => '1226015094',
    'message' => 'Alle anzeigen'
  },
  'edit subscription title' => {
    'lastUpdated' => '1240755672',
    'message' => 'Abonnement ändern'
  },
  'execute on subscription' => {
    'lastUpdated' => '1241304245',
    'message' => 'Bei Bestellung ausführen'
  },
  'execute on subscription description' => {
    'lastUpdated' => '1250942634',
    'message' => 'Ein (Perl-)Skript, das ausgeführt wird, wenn jemand abonniert und gezahlt hat.'
  },
  'expire subscription codes' => {
    'lastUpdated' => '1241304162',
    'message' => 'Ablauf Abocodes'
  },
  'formFooter' => {
    'lastUpdated' => '1241304268',
    'message' => 'Formularabschluss'
  },
  'formHeader' => {
    'lastUpdated' => '1240779199',
    'message' => 'Formularkopf'
  },
  'generate batch' => {
    'lastUpdated' => '1240741056',
    'message' => 'Codeserie generieren'
  },
  'hasAddedToCart' => {
    'lastUpdated' => '1241303869',
    'message' => 'Eine Bedingung, die angibt, dass der Benutzer das Abonnement in den Warenkorb aufgenommen hat und der "Danke"-Text angezeigt werden kann.'
  },
  'help redeem code template title' => {
    'lastUpdated' => '1241303508',
    'message' => 'Vorlage Einlösung Abocode'
  },
  'list codes in batch' => {
    'lastUpdated' => '1240740803',
    'message' => 'Auflisten der Codes in dieser Serie'
  },
  'listSubscriptionCodes title' => {
    'lastUpdated' => '1241303782',
    'message' => 'Verwalten Abocodes'
  },
  'manage batches' => {
    'lastUpdated' => '1240741528',
    'message' => 'Codeserien verwalten'
  },
  'manage codes' => {
    'lastUpdated' => '1241303752',
    'message' => 'Verwalten Abocodes'
  },
  'manage subscriptions' => {
    'lastUpdated' => '1240778941',
    'message' => 'Abonnements'
  },
  'message' => {
    'lastUpdated' => '1243494685',
    'message' => 'Die Info über das Ergebnis Ihrer Aktion. Abhängig davon enthält diese, dass Sie einen Code eingeben können, dass Sie den Code falsch angegeben haben oder ob Sie den Code richtig eingesetzt haben.'
  },
  'no association error' => {
    'lastUpdated' => '1251896982',
    'message' => 'Sie müssen diese Codeserie mit mindestens einem Abonnement verbinden.'
  },
  'no description error' => {
    'lastUpdated' => '1251896993',
    'message' => 'Sie müssen eine Beschreibung eingeben'
  },
  'no subscription code batches' => {
    'lastUpdated' => '1251897054',
    'message' => 'Es wurde noch keine Codeserie für die Abonnements wurde erstellt. Benutzen Sie das Untermenue rechts, um eine Codeserie zu erstellen.'
  },
  'no subscriptions' => {
    'lastUpdated' => '1240879978',
    'message' => 'Es gibt noch keine Abonnements. Sie können Abo\'s hinzufügen mit der Option "Abonnement hinzufügen"'
  },
  'noc' => {
    'lastUpdated' => '1240741505',
    'message' => 'Anzahl der Abonnementscodes in der Serie'
  },
  'noc description' => {
    'lastUpdated' => '1241303543',
    'message' => 'Anzahl der zu generierenden Codes'
  },
  'price' => {
    'lastUpdated' => '1240741414',
    'message' => 'Abonnementspreis (####.##)'
  },
  'purchase button' => {
    'lastUpdated' => '1240741452',
    'message' => 'In den Warenkorb legen'
  },
  'purchaseButton' => {
    'lastUpdated' => '1240741477',
    'message' => 'Kaufen'
  },
  'recurring subscription' => {
    'lastUpdated' => '1240741372',
    'message' => 'Automatische Verlängerung?'
  },
  'recurring subscription description' => {
    'lastUpdated' => '1240741341',
    'message' => 'Wenn "Ja", wird der Kunde nach Ablauf der Abonnementszeit belastet und das Abonnement wird erneuert. Wenn "Nein", läuft das Abonnement automatisch ab.'
  },
  'redeem code' => {
    'lastUpdated' => '1240880011',
    'message' => 'Einen Abonnementscode einlösen.'
  },
  'redeem code ask for code' => {
    'lastUpdated' => '1240880274',
    'message' => 'Bitte geben Sie Ihren Abocode ein.'
  },
  'redeem code failure' => {
    'lastUpdated' => '1251897115',
    'message' => 'Sie haben einen Code eingegeben, der falsch ist, bereits verbraucht oder abgelaufen. bitte geben Sie einen anderen Code ein.'
  },
  'redeem code success' => {
    'lastUpdated' => '1251897172',
    'message' => 'Sie haben erfolgreich abonniert. Sie können den unten Code eingeben.'
  },
  'redeem subscription code template' => {
    'lastUpdated' => '1251897209',
    'message' => 'Abonnement einlösen Tempalte'
  },
  'redeem subscription code template help' => {
    'lastUpdated' => '1251897252',
    'message' => 'Wählen Sie ein Template für die Seite, auf der Benutzer Abonnements einlösen können.'
  },
  'redeemCodeLabel' => {
    'lastUpdated' => '1240880235',
    'message' => 'Abocode einlösen'
  },
  'redeemCodeUrl' => {
    'lastUpdated' => '1251897295',
    'message' => 'URL um ein Abonnement einzulösen. Wenn es keine Abonnementcodes gibt, bleibt dies leer.'
  },
  'select' => {
    'lastUpdated' => '1240778962',
    'message' => 'Selektion anzeigen'
  },
  'selection batch name' => {
    'lastUpdated' => '1240880141',
    'message' => 'Name Codeserie'
  },
  'selection created' => {
    'lastUpdated' => '1250942384',
    'message' => 'Erstellungsdatum zwischen'
  },
  'selection message' => {
    'lastUpdated' => '1250942419',
    'message' => 'Sie können Codes selektieren durch:'
  },
  'selection used' => {
    'lastUpdated' => '1250942443',
    'message' => 'Datum der Verwendung zwischen'
  },
  'status' => {
    'lastUpdated' => '1240778975',
    'message' => 'Status'
  },
  'subscription description' => {
    'lastUpdated' => '1251896798',
    'message' => 'Beschreibung'
  },
  'subscription description description' => {
    'lastUpdated' => '1241303582',
    'message' => 'Detaillierte Beschreibung des Abonnements.'
  },
  'subscription duration' => {
    'lastUpdated' => '1241303682',
    'message' => 'Laufzeit'
  },
  'subscription duration description' => {
    'lastUpdated' => '1251897349',
    'message' => 'Die Länge einer Abonnementeinheit. Sie bezahlen pro Monat, jedes  Halbjahr, etc.'
  },
  'subscription group' => {
    'lastUpdated' => '1251897397',
    'message' => 'Der Gruppe beitreten'
  },
  'subscription group description' => {
    'lastUpdated' => '1251897422',
    'message' => 'Wenn der Nutzer bezahlt hat, wird er zu dieser Gruppe hinzugefügt'
  },
  'subscription karma' => {
    'lastUpdated' => '1251897428',
    'message' => 'Karma'
  },
  'subscription karma description' => {
    'lastUpdated' => '1251897455',
    'message' => 'Die Menge an Karma, die der Benutzer erhält, nachdem er abonniert hat.'
  },
  'subscription name' => {
    'lastUpdated' => '1240880085',
    'message' => 'Abo-Name'
  },
  'subscription name description' => {
    'lastUpdated' => '1240880106',
    'message' => 'Der Name des Abonnements'
  },
  'subscription price' => {
    'lastUpdated' => '1240880027',
    'message' => 'Abopreis'
  },
  'subscription price description' => {
    'lastUpdated' => '1241303643',
    'message' => 'Preis für das Abonnement.'
  },
  'subscription template' => {
    'lastUpdated' => '1241303656',
    'message' => 'Vorlage Abonnement'
  },
  'subscriptionId' => {
    'lastUpdated' => '1241303611',
    'message' => 'Subscription Id'
  },
  'template' => {
    'lastUpdated' => '1240778997',
    'message' => 'Vorlage Abonnement'
  },
  'template help' => {
    'lastUpdated' => '1250942671',
    'message' => 'Wählen Sie die Vorlage um das Abonnement anzuzeigen.'
  },
  'thank you message' => {
    'lastUpdated' => '1240880069',
    'message' => '"Danke"-Nachricht'
  },
  'thank you message help' => {
    'lastUpdated' => '1250942557',
    'message' => 'Verwenden Sie dieses Feld für eine Nachricht an die Benutzer, die gerade ein Abonnement in den Warenkorb gelegt haben. Bitte beachten Sie, dass das Abonnement nicht aktiviert wird, bevor der Benutzer sich abgemeldet hat.'
  },
  'topicName' => {
    'lastUpdated' => '1240880044',
    'message' => 'Abonnements'
  },
  'useSalesTax' => {
    'lastUpdated' => '1240779028',
    'message' => 'Mwhrwertsteuerplichtig?'
  },
  'useSalesTax description' => {
    'lastUpdated' => '1240779058',
    'message' => 'Ist dieses Abonnement mehrwertsteuerpflichtig?'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Subscription.pm <==
package WebGUI::i18n::German::Asset_Subscription;
use utf8;
our $I18N = {
  'add subscription' => {
    'lastUpdated' => '1240740261',
    'message' => 'Neues Abonnement hinzufügen'
  },
  'and' => {
    'lastUpdated' => '1226015077',
    'message' => 'und'
  },
  'assetName' => {
    'lastUpdated' => '1240740271',
    'message' => 'Abonnement'
  },
  'association' => {
    'lastUpdated' => '1240779161',
    'message' => 'Mit Abonnement verbinden'
  },
  'association description' => {
    'lastUpdated' => '1240779130',
    'message' => 'Welche/s Abonnement/s wurden mit den generierten Codes abgeschlossen? '
  },
  'batch description' => {
    'lastUpdated' => '1240740441',
    'message' => 'Codeserie Beschreibung'
  },
  'batch description description' => {
    'lastUpdated' => '1241303911',
    'message' => 'Beschreibung der Codeserie'
  },
  'batch id' => {
    'lastUpdated' => '1240740396',
    'message' => 'CodesatzId'
  },
  'batch name' => {
    'lastUpdated' => '1240740426',
    'message' => 'Name der Codeserie'
  },
  'batch name description' => {
    'lastUpdated' => '1240778906',
    'message' => 'Geben Sie eine Bezeichnung für diese Codeserie an'
  },
  'batchDescription' => {
    'lastUpdated' => '1240740538',
    'message' => 'Die Beschreibung der Codeserie, die mit dem Abonnementscode zusammenhängt.'
  },
  'code' => {
    'lastUpdated' => '1240740240',
    'message' => 'Code'
  },
  'code description' => {
    'lastUpdated' => '1240740623',
    'message' => 'Der Abonnementscode, den Sie einlösen möchten'
  },
  'code length' => {
    'lastUpdated' => '1240740682',
    'message' => 'Länge Abonnementscode'
  },
  'code length description' => {
    'lastUpdated' => '1241303410',
    'message' => 'Anzahl der Zeichen in den generierten Codes. Die Länge der Codes soll minimum 10 Zeichen betragen.'
  },
  'code length error' => {
    'lastUpdated' => '1241303975',
    'message' => 'Sie sollten einen Abocode mit einer Länge von 10 bis max. 64 Zeichen eingegeben.'
  },
  'codeControls' => {
    'lastUpdated' => '1241304069',
    'message' => 'Eine Serie von Links für die Erstellung von Codeserien und das Auflisten von Abocodes und Codserien.'
  },
  'codeForm' => {
    'lastUpdated' => '1240779279',
    'message' => 'Das Formular in das der Benutzer seinen Abonnementscode eingeben kann.'
  },
  'codes expire' => {
    'lastUpdated' => '1240740765',
    'message' => 'Codes ungültig ab'
  },
  'codes expire description' => {
    'lastUpdated' => '1240880329',
    'message' => 'Der Abocode muss bis zu diesem Datum eingelöst werden.'
  },
  'continueShoppingUrl' => {
    'lastUpdated' => '1240879864',
    'message' => 'Eine URL zum Reset des Produkts, damit der Benutzer weiter einkaufen kann'
  },
  'create batch error' => {
    'lastUpdated' => '1241304114',
    'message' => 'Es gab einen Fehler bei der Erstellung von der Codeserie.'
  },
  'create batch menu' => {
    'lastUpdated' => '1241304204',
    'message' => 'Codeserie generieren'
  },
  'creation date' => {
    'lastUpdated' => '1240778919',
    'message' => 'Erstellungsdatum'
  },
  'dateUsed' => {
    'lastUpdated' => '1243494558',
    'message' => 'Datum Inanspruchnahme'
  },
  'default thank you message' => {
    'lastUpdated' => '1254902412',
    'message' => 'Das Abonnement wurde in den Warenkorb gelegt.'
  },
  'delete batch confirm' => {
    'lastUpdated' => '1250942315',
    'message' => 'Möchten Sie diese Codeserie wirklich löschen?'
  },
  'delete codes' => {
    'lastUpdated' => '1240779181',
    'message' => 'Alle diese Codes löschen'
  },
  'delete subscription confirm' => {
    'lastUpdated' => '1241304136',
    'message' => 'Möchten Sie dieses Abonnement wirklich löschen?'
  },
  'display all' => {
    'lastUpdated' => '1226015094',
    'message' => 'Alle anzeigen'
  },
  'edit subscription title' => {
    'lastUpdated' => '1240755672',
    'message' => 'Abonnement ändern'
  },
  'execute on subscription' => {
    'lastUpdated' => '1241304245',
    'message' => 'Bei Bestellung ausführen'
  },
  'execute on subscription description' => {
    'lastUpdated' => '1250942634',
    'message' => 'Ein (Perl-)Skript, das ausgeführt wird, wenn jemand abonniert und gezahlt hat.'
  },
  'expire subscription codes' => {
    'lastUpdated' => '1241304162',
    'message' => 'Ablauf Abocodes'
  },
  'formFooter' => {
    'lastUpdated' => '1241304268',
    'message' => 'Formularabschluss'
  },
  'formHeader' => {
    'lastUpdated' => '1240779199',
    'message' => 'Formularkopf'
  },
  'generate batch' => {
    'lastUpdated' => '1240741056',
    'message' => 'Codeserie generieren'
  },
  'hasAddedToCart' => {
    'lastUpdated' => '1241303869',
    'message' => 'Eine Bedingung, die angibt, dass der Benutzer das Abonnement in den Warenkorb aufgenommen hat und der "Danke"-Text angezeigt werden kann.'
  },
  'help redeem code template title' => {
    'lastUpdated' => '1241303508',
    'message' => 'Vorlage Einlösung Abocode'
  },
  'list codes in batch' => {
    'lastUpdated' => '1240740803',
    'message' => 'Auflisten der Codes in dieser Serie'
  },
  'listSubscriptionCodes title' => {
    'lastUpdated' => '1241303782',
    'message' => 'Verwalten Abocodes'
  },
  'manage batches' => {
    'lastUpdated' => '1240741528',
    'message' => 'Codeserien verwalten'
  },
  'manage codes' => {
    'lastUpdated' => '1241303752',
    'message' => 'Verwalten Abocodes'
  },
  'manage subscriptions' => {
    'lastUpdated' => '1240778941',
    'message' => 'Abonnements'
  },
  'message' => {
    'lastUpdated' => '1243494685',
    'message' => 'Die Info über das Ergebnis Ihrer Aktion. Abhängig davon enthält diese, dass Sie einen Code eingeben können, dass Sie den Code falsch angegeben haben oder ob Sie den Code richtig eingesetzt haben.'
  },
  'no association error' => {
    'lastUpdated' => '1251896982',
    'message' => 'Sie müssen diese Codeserie mit mindestens einem Abonnement verbinden.'
  },
  'no description error' => {
    'lastUpdated' => '1251896993',
    'message' => 'Sie müssen eine Beschreibung eingeben'
  },
  'no subscription code batches' => {
    'lastUpdated' => '1315601231',
    'message' => 'Es wurde noch keine Codeserie für die Abonnements erstellt. Benutzen Sie das Untermenü rechts, um eine Codeserie zu erstellen.'
  },
  'no subscriptions' => {
    'lastUpdated' => '1240879978',
    'message' => 'Es gibt noch keine Abonnements. Sie können Abo\'s hinzufügen mit der Option "Abonnement hinzufügen"'
  },
  'noc' => {
    'lastUpdated' => '1240741505',
    'message' => 'Anzahl der Abonnementscodes in der Serie'
  },
  'noc description' => {
    'lastUpdated' => '1241303543',
    'message' => 'Anzahl der zu generierenden Codes'
  },
  'price' => {
    'lastUpdated' => '1240741414',
    'message' => 'Abonnementspreis (####.##)'
  },
  'purchase button' => {
    'lastUpdated' => '1240741452',
    'message' => 'In den Warenkorb legen'
  },
  'purchaseButton' => {
    'lastUpdated' => '1240741477',
    'message' => 'Kaufen'
  },
  'recurring subscription' => {
    'lastUpdated' => '1240741372',
    'message' => 'Automatische Verlängerung?'
  },
  'recurring subscription description' => {
    'lastUpdated' => '1240741341',
    'message' => 'Wenn "Ja", wird der Kunde nach Ablauf der Abonnementszeit belastet und das Abonnement wird erneuert. Wenn "Nein", läuft das Abonnement automatisch ab.'
  },
  'redeem code' => {
    'lastUpdated' => '1240880011',
    'message' => 'Einen Abonnementscode einlösen.'
  },
  'redeem code ask for code' => {
    'lastUpdated' => '1240880274',
    'message' => 'Bitte geben Sie Ihren Abocode ein.'
  },
  'redeem code failure' => {
    'lastUpdated' => '1251897115',
    'message' => 'Sie haben einen Code eingegeben, der falsch ist, bereits verbraucht oder abgelaufen. bitte geben Sie einen anderen Code ein.'
  },
  'redeem code success' => {
    'lastUpdated' => '1251897172',
    'message' => 'Sie haben erfolgreich abonniert. Sie können den unten Code eingeben.'
  },
  'redeem subscription code template' => {
    'lastUpdated' => '1251897209',
    'message' => 'Abonnement einlösen Tempalte'
  },
  'redeem subscription code template help' => {
    'lastUpdated' => '1251897252',
    'message' => 'Wählen Sie ein Template für die Seite, auf der Benutzer Abonnements einlösen können.'
  },
  'redeemCodeLabel' => {
    'lastUpdated' => '1240880235',
    'message' => 'Abocode einlösen'
  },
  'redeemCodeUrl' => {
    'lastUpdated' => '1251897295',
    'message' => 'URL um ein Abonnement einzulösen. Wenn es keine Abonnementcodes gibt, bleibt dies leer.'
  },
  'select' => {
    'lastUpdated' => '1240778962',
    'message' => 'Selektion anzeigen'
  },
  'selection batch name' => {
    'lastUpdated' => '1240880141',
    'message' => 'Name Codeserie'
  },
  'selection created' => {
    'lastUpdated' => '1250942384',
    'message' => 'Erstellungsdatum zwischen'
  },
  'selection message' => {
    'lastUpdated' => '1250942419',
    'message' => 'Sie können Codes selektieren durch:'
  },
  'selection used' => {
    'lastUpdated' => '1250942443',
    'message' => 'Datum der Verwendung zwischen'
  },
  'status' => {
    'lastUpdated' => '1240778975',
    'message' => 'Status'
  },
  'subscription description' => {
    'lastUpdated' => '1251896798',
    'message' => 'Beschreibung'
  },
  'subscription description description' => {
    'lastUpdated' => '1241303582',
    'message' => 'Detaillierte Beschreibung des Abonnements.'
  },
  'subscription duration' => {
    'lastUpdated' => '1241303682',
    'message' => 'Laufzeit'
  },
  'subscription duration description' => {
    'lastUpdated' => '1251897349',
    'message' => 'Die Länge einer Abonnementeinheit. Sie bezahlen pro Monat, jedes  Halbjahr, etc.'
  },
  'subscription group' => {
    'lastUpdated' => '1251897397',
    'message' => 'Der Gruppe beitreten'
  },
  'subscription group description' => {
    'lastUpdated' => '1251897422',
    'message' => 'Wenn der Nutzer bezahlt hat, wird er zu dieser Gruppe hinzugefügt'
  },
  'subscription karma' => {
    'lastUpdated' => '1251897428',
    'message' => 'Karma'
  },
  'subscription karma description' => {
    'lastUpdated' => '1251897455',
    'message' => 'Die Menge an Karma, die der Benutzer erhält, nachdem er abonniert hat.'
  },
  'subscription name' => {
    'lastUpdated' => '1240880085',
    'message' => 'Abo-Name'
  },
  'subscription name description' => {
    'lastUpdated' => '1240880106',
    'message' => 'Der Name des Abonnements'
  },
  'subscription price' => {
    'lastUpdated' => '1240880027',
    'message' => 'Abopreis'
  },
  'subscription price description' => {
    'lastUpdated' => '1241303643',
    'message' => 'Preis für das Abonnement.'
  },
  'subscription template' => {
    'lastUpdated' => '1241303656',
    'message' => 'Vorlage Abonnement'
  },
  'subscriptionId' => {
    'lastUpdated' => '1241303611',
    'message' => 'Subscription Id'
  },
  'template' => {
    'lastUpdated' => '1240778997',
    'message' => 'Vorlage Abonnement'
  },
  'template help' => {
    'lastUpdated' => '1250942671',
    'message' => 'Wählen Sie die Vorlage um das Abonnement anzuzeigen.'
  },
  'thank you message' => {
    'lastUpdated' => '1240880069',
    'message' => '"Danke"-Nachricht'
  },
  'thank you message help' => {
    'lastUpdated' => '1250942557',
    'message' => 'Verwenden Sie dieses Feld für eine Nachricht an die Benutzer, die gerade ein Abonnement in den Warenkorb gelegt haben. Bitte beachten Sie, dass das Abonnement nicht aktiviert wird, bevor der Benutzer sich abgemeldet hat.'
  },
  'topicName' => {
    'lastUpdated' => '1240880044',
    'message' => 'Abonnements'
  },
  'useSalesTax' => {
    'lastUpdated' => '1240779028',
    'message' => 'Mwhrwertsteuerplichtig?'
  },
  'useSalesTax description' => {
    'lastUpdated' => '1240779058',
    'message' => 'Ist dieses Abonnement mehrwertsteuerpflichtig?'
  }
}
;

1;
